@@ -1,5 +1,4 @@
 import argparse
-import sys
 
 from .build import build_command
 from .dep import dep_command
@@ -7,13 +6,8 @@ from .version import version_command
 
 
 def hatchling():
-    # TODO: remove when we drop Python 2
-    if sys.version_info[0] < 3:  # no cov
-        parser = argparse.ArgumentParser(prog='hatchling')
-        subparsers = parser.add_subparsers()
-    else:
-        parser = argparse.ArgumentParser(prog='hatchling', allow_abbrev=False)
-        subparsers = parser.add_subparsers(required=True)
+    parser = argparse.ArgumentParser(prog='hatchling', allow_abbrev=False)
+    subparsers = parser.add_subparsers(required=True)
 
     defaults = {'metavar': ''}
 
